@@ -2,7 +2,7 @@ package Mojo::Redis::Cache;
 use Mojo::Base -base;
 
 use Mojo::JSON;
-use Protocol::Redis;
+use Protocol::Redis::Faster;
 use Scalar::Util 'blessed';
 use Storable    ();
 use Time::HiRes ();
@@ -12,7 +12,7 @@ use constant OFFLINE => $ENV{MOJO_REDIS_CACHE_OFFLINE};
 has connection => sub {
   OFFLINE
     ? shift->_offline_connection
-    : shift->redis->_dequeue->protocol(Protocol::Redis->new(api => 1))->encoding(undef);
+    : shift->redis->_dequeue->protocol(Protocol::Redis::Faster->new(api => 1))->encoding(undef);
 };
 has deserialize    => sub { \&Storable::thaw };
 has default_expire => 600;
